@@ -235,18 +235,6 @@ fn build_cloneable(b: &mut Bencher) {
     });
 }
 
-fn access_column(b: &mut Bencher) {
-    let mut world = World::new();
-    let _enta = world.spawn((Position(0.0), Velocity(0.0)));
-    let _entb = world.spawn((true, 12));
-    let entc = world.spawn((Position(3.0),));
-    let _entd = world.spawn((13, true, 4.0));
-    let column = world.column::<Position>();
-    b.iter(|| {
-        let _comp = bencher::black_box(column.get(entc).unwrap());
-    });
-}
-
 fn access_view(b: &mut Bencher) {
     let mut world = World::new();
     let _enta = world.spawn((Position(0.0), Velocity(0.0)));
@@ -288,7 +276,6 @@ benchmark_group!(
     iterate_mut_cached_100_by_50,
     build,
     build_cloneable,
-    access_column,
     access_view,
     spawn_buffered,
 );
