@@ -11,9 +11,9 @@ use core::ptr::{self, NonNull};
 use crate::alloc::alloc::{alloc, dealloc, Layout};
 use crate::alloc::vec::Vec;
 use crate::archetype::TypeInfo;
-use crate::Entity;
 use crate::World;
 use crate::{align, DynamicBundle};
+use crate::{Bundle, Entity};
 
 /// Records operations for future application to a [`World`]
 ///
@@ -30,6 +30,8 @@ use crate::{align, DynamicBundle};
 /// ```
 pub struct CommandBuffer {
     entities: Vec<EntityIndex>,
+    remove_comps: Vec<RemovedComps>,
+    despawn_ent: Vec<Entity>,
     storage: NonNull<u8>,
     layout: Layout,
     cursor: usize,
@@ -89,6 +91,22 @@ impl CommandBuffer {
         });
     }
 
+    /// Remove components from `entity` if they exist
+    pub fn remove<T: Bundle + 'static>(&mut self, ent: Entity) {
+        fn remove_bundle_and_ignore_result<T: Bundle + 'static>(world: &mut World, ents: Entity) {
+            let _ = world.remove::<T>(ents);
+        }
+        self.remove_comps.push(RemovedComps {
+            remove: remove_bundle_and_ignore_result::<T>,
+            entity: ent,
+        });
+    }
+
+    /// Despawn `entity` from World
+    pub fn despawn(&mut self, entity: Entity) {
+        self.despawn_ent.push(entity);
+    }
+
     /// Spawn a new entity with `components`
     ///
     /// If the [`Entity`] is needed immediately, consider combining [`World::reserve_entity`] with
@@ -124,6 +142,15 @@ impl CommandBuffer {
                 }
             }
         }
+
+        for comp in self.remove_comps.iter() {
+            (comp.remove)(world, comp.entity);
+        }
+
+        for entity in self.despawn_ent.iter() {
+            let _ = world.despawn(*entity);
+        }
+
         self.clear();
     }
 
@@ -148,6 +175,8 @@ impl CommandBuffer {
                 info.ty.drop(self.storage.as_ptr().add(info.offset));
             }
         }
+        self.remove_comps.clear();
+        self.despawn_ent.clear();
     }
 }
 
@@ -175,6 +204,8 @@ impl Default for CommandBuffer {
             cursor: 0,
             components: Vec::new(),
             ids: Vec::new(),
+            despawn_ent: Vec::new(),
+            remove_comps: Vec::new(),
         }
     }
 }
@@ -224,6 +255,12 @@ struct EntityIndex {
     first_component: usize,
 }
 
+/// Data required to remove components from 'entity'
+struct RemovedComps {
+    remove: fn(&mut World, Entity),
+    entity: Entity,
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
