@@ -330,6 +330,17 @@ fn build_builder_clone() {
     assert_eq!(b.get::<i32>(), Some(&123));
 }
 
+#[test]
+fn cloned_builder() {
+    let mut builder = EntityBuilderClone::new();
+    builder.add(String::from("abc")).add(123);
+
+    let mut world = World::new();
+    let e = world.spawn(&builder.build().clone());
+    assert_eq!(*world.get::<String>(e).unwrap(), "abc");
+    assert_eq!(*world.get::<i32>(e).unwrap(), 123);
+}
+
 #[test]
 #[cfg(feature = "macros")]
 fn build_dynamic_bundle() {
@@ -458,6 +469,30 @@ fn spawn_buffered_entity() {
     assert_eq!(*world.get::<u8>(ent3).unwrap(), 2);
 }
 
+#[test]
+fn despawn_buffered_entity() {
+    let mut world = World::new();
+    let mut buffer = CommandBuffer::new();
+    let ent = world.spawn((1, true));
+    buffer.despawn(ent);
+
+    buffer.run_on(&mut world);
+    assert!(!world.contains(ent));
+}
+
+#[test]
+fn remove_buffered_component() {
+    let mut world = World::new();
+    let mut buffer = CommandBuffer::new();
+    let ent = world.spawn((7, true, "hecs"));
+
+    buffer.remove::<(i32, &str)>(ent);
+    buffer.run_on(&mut world);
+
+    assert!(world.get::<&str>(ent).is_err());
+    assert!(world.get::<i32>(ent).is_err());
+}
+
 #[test]
 #[should_panic(expected = "already borrowed")]
 fn illegal_borrow() {
@@ -648,13 +683,13 @@ fn query_batched() {
 #[test]
 fn spawn_batch() {
     let mut world = World::new();
-    world.spawn_batch((0..100).map(|x| (x, "abc")));
+    world.spawn_batch((0..10).map(|x| (x, "abc")));
     let entities = world
         .query::<&i32>()
         .iter()
         .map(|(_, &x)| x)
         .collect::<Vec<_>>();
-    assert_eq!(entities.len(), 100);
+    assert_eq!(entities.len(), 10);
 }
 
 #[test]
@@ -820,3 +855,19 @@ fn len() {
     world.clear();
     assert_eq!(world.len(), 0);
 }
+
+#[test]
+fn take() {
+    let mut world_a = World::new();
+    let e = world_a.spawn(("abc".to_string(), 42));
+    let f = world_a.spawn(("def".to_string(), 17));
+    let mut world_b = World::new();
+    let e2 = world_b.spawn(world_a.take(e).unwrap());
+    assert!(!world_a.contains(e));
+    assert_eq!(*world_b.get::<String>(e2).unwrap(), "abc");
+    assert_eq!(*world_b.get::<i32>(e2).unwrap(), 42);
+    assert_eq!(*world_a.get::<String>(f).unwrap(), "def");
+    assert_eq!(*world_a.get::<i32>(f).unwrap(), 17);
+    world_b.take(e2).unwrap();
+    assert!(!world_b.contains(e2));
+}
